@@ -7,7 +7,7 @@
 // permissions and limitations relating to use of the SAFE Network Software.
 
 use color_eyre::{eyre::bail, eyre::eyre, eyre::WrapErr, Help, Report, Result};
-use prettytable::Table;
+use comfy_table::Table;
 use serde::{Deserialize, Serialize};
 use sn_api::{NodeConfig, PublicKey};
 use std::{
@@ -118,32 +118,46 @@ impl Config {
         pb.pop();
         fs::create_dir_all(pb.as_path()).await?;
 
-        let settings: Settings;
-        if cli_config_path.exists() {
+        let settings = if cli_config_path.exists() {
             let content = fs::read(&cli_config_path).await.wrap_err_with(|| {
                 format!(
                     "Error reading config file from '{}'",
                     cli_config_path.display(),
                 )
             })?;
-            settings = serde_json::from_slice(&content).wrap_err_with(|| {
-                format!(
-                    "Format of the config file at '{}' is not valid and couldn't be parsed",
-                    cli_config_path.display()
-                )
-            })?;
-            debug!(
-                "Config settings retrieved from '{}': {:?}",
-                cli_config_path.display(),
+            if content.is_empty() {
+                // During the CLI test run, when running with more than one thread, i.e., running
+                // multiple instances of safe at the same time, it seems to be possible for there
+                // to be an empty config file, even though I can't determine how the scenario
+                // occurs.
+                //
+                // Checking if the content is empty prevents an error from trying to deserialize an
+                // empty byte array. We can just return the default empty settings.
+                //
+                // This shouldn't have any adverse effects on users, since concurrently running
+                // multiple instances of safe is unlikely.
+                Settings::default()
+            } else {
+                let settings = serde_json::from_slice(&content).wrap_err_with(|| {
+                    format!(
+                        "Format of the config file at '{}' is not valid and couldn't be parsed",
+                        cli_config_path.display()
+                    )
+                })?;
+                debug!(
+                    "Config settings retrieved from '{}': {:?}",
+                    cli_config_path.display(),
+                    settings
+                );
                 settings
-            );
+            }
         } else {
-            settings = Settings::default();
             debug!(
                 "Empty config file created at '{}'",
                 cli_config_path.display()
             );
-        }
+            Settings::default()
+        };
 
         let config = Config {
             settings,
@@ -319,8 +333,8 @@ impl Config {
 
     pub async fn print_networks(&self) {
         let mut table = Table::new();
-        table.add_row(row![bFg->"Networks"]);
-        table.add_row(row![bFg->"Current", bFg->"Network name", bFg->"Connection info"]);
+        table.add_row(&vec!["Networks"]);
+        table.add_row(&vec!["Current", "Network name", "Connection info"]);
         let current_node_config = match self.read_current_node_config().await {
             Ok((_, current_conn_info)) => Some(current_conn_info),
             Err(_) => None, // we simply ignore the error, none of the networks is currently active/set in the system
@@ -333,10 +347,10 @@ impl Config {
                     current = "*";
                 }
             }
-            table.add_row(row![current, network_name, net_info]);
+            table.add_row(&vec![current, network_name, &format!("{:?}", net_info)]);
         }
 
-        table.printstd();
+        println!("{table}");
     }
 
     //
@@ -527,6 +541,25 @@ mod constructor {
 
         Ok(())
     }
+
+    #[tokio::test]
+    async fn given_an_empty_config_file_empty_settings_should_be_returned() -> Result<()> {
+        let tmp_dir = assert_fs::TempDir::new()?;
+        let cli_config_file = tmp_dir.child(".safe/cli/config.json");
+        cli_config_file.touch()?;
+        let node_config_file = tmp_dir.child(".safe/node/node_connection_info.config");
+        let config = Config::new(
+            PathBuf::from(cli_config_file.path()),
+            PathBuf::from(node_config_file.path()),
+        )
+        .await?;
+
+        assert_eq!(0, config.settings.networks.len());
+        assert_eq!(cli_config_file.path(), config.cli_config_path.as_path());
+        assert_eq!(node_config_file.path(), config.node_config_path.as_path());
+
+        Ok(())
+    }
 }
 
 #[cfg(test)]
